@@ -17,9 +17,12 @@ def create_footprint(
 ):
     logging.info("creating footprint ...")
 
-    footprint_name, datasheet_link, footprint_shape = get_footprint_info(
-        footprint_component_uuid
-    )
+    (
+        footprint_name,
+        datasheet_link,
+        footprint_shape,
+        translation,
+    ) = get_footprint_info(footprint_component_uuid)
 
     if skip_existing:
         # check if footprint already exists:
@@ -36,7 +39,7 @@ def create_footprint(
 
     class footprint_info:
         def __init__(
-            self, footprint_name, output_dir, footprint_lib, model_base_variable
+            self, footprint_name, output_dir, footprint_lib, model_base_variable, origin
         ):
             self.max_X, self.max_Y, self.min_X, self.min_Y = (
                 -10000,
@@ -48,12 +51,14 @@ def create_footprint(
             self.output_dir = output_dir
             self.footprint_lib = footprint_lib
             self.model_base_variable = model_base_variable
+            self.origin = origin
 
     footprint_info = footprint_info(
         footprint_name=footprint_name,
         output_dir=output_dir,
         footprint_lib=footprint_lib,
         model_base_variable=model_base_variable,
+        origin=translation,
     )
 
     # for each line in data : use the appropriate handler
@@ -68,6 +73,14 @@ def create_footprint(
         else:
             handlers.get(model)(args[1:], kicad_mod, footprint_info)
 
+    kicad_mod.insert(Translation(-mil2mm(translation[0]), -mil2mm(translation[1])))
+
+    # Translate the footprint max and min values to the origin
+    footprint_info.max_X -= mil2mm(translation[0])
+    footprint_info.max_Y -= mil2mm(translation[1])
+    footprint_info.min_X -= mil2mm(translation[0])
+    footprint_info.min_Y -= mil2mm(translation[1])
+
     # set general values
     kicad_mod.append(
         Text(
@@ -103,14 +116,6 @@ def create_footprint(
         )
     )
 
-    # translate the footprint to be centered around 0,0
-    kicad_mod.insert(
-        Translation(
-            -(footprint_info.min_X + footprint_info.max_X) / 2,
-            -(footprint_info.min_Y + footprint_info.max_Y) / 2,
-        )
-    )
-
     if not os.path.exists(f"{output_dir}/{footprint_lib}"):
         os.makedirs(f"{output_dir}/{footprint_lib}")
 
@@ -139,6 +144,8 @@ def get_footprint_info(footprint_component_uuid):
         return ()
 
     footprint_shape = data["result"]["dataStr"]["shape"]
+    x = data["result"]["dataStr"]["head"]["x"]
+    y = data["result"]["dataStr"]["head"]["y"]
     try:
         datasheet_link = data["result"]["dataStr"]["head"]["c_para"]["link"]
     except:
@@ -159,4 +166,4 @@ def get_footprint_info(footprint_component_uuid):
             "Could not retrieve components information from EASYEDA, default name 'NoName'."
         )
 
-    return (footprint_name, datasheet_link, footprint_shape)
+    return (footprint_name, datasheet_link, footprint_shape, (x, y))
